@@ -9,7 +9,9 @@ import Map from "./components/Map";
 import Morris from "./components/Morris";
 import LayeredMap from "./components/LayeredMap";
 import LeafletMap from "./components/LeafletMap";
+import DeckGLMap from "./components/DeckGLMap";
 import PriorPosteriorDistribution from "./components/PriorPosteriorDistribution";
+import WellCompletions from "./components/WellCompletions";
 
 export {
     HistoryMatch,
@@ -18,4 +20,6 @@ export {
     LayeredMap,
     PriorPosteriorDistribution,
     LeafletMap,
+    DeckGLMap,
+    WellCompletions,
 };
