@@ -1,15 +1,19 @@
+from .DeckGLMap import DeckGLMap
 from .HistoryMatch import HistoryMatch
 from .LayeredMap import LayeredMap
 from .LeafletMap import LeafletMap
 from .Map import Map
 from .Morris import Morris
 from .PriorPosteriorDistribution import PriorPosteriorDistribution
+from .WellCompletions import WellCompletions
 
 __all__ = [
+    "DeckGLMap",
     "HistoryMatch",
     "LayeredMap",
     "LeafletMap",
     "Map",
     "Morris",
-    "PriorPosteriorDistribution"
+    "PriorPosteriorDistribution",
+    "WellCompletions"
 ]
\ No newline at end of file
